==> aws-cdk-scala-stepfunctions_2.12-0.2.0-sources.jar: io/burkard/cdk/services/stepfunctions/CallAwsServiceProps.scala <==
package io.burkard.cdk.services.stepfunctions

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CallAwsServiceProps {

  def apply(
    service: String,
    iamResources: List[String],
    action: String,
    iamAction: Option[String] = None,
    resultPath: Option[String] = None,
    resultSelector: Option[Map[String, _]] = None,
    heartbeat: Option[software.amazon.awscdk.Duration] = None,
    integrationPattern: Option[software.amazon.awscdk.services.stepfunctions.IntegrationPattern] = None,
    outputPath: Option[String] = None,
    comment: Option[String] = None,
    inputPath: Option[String] = None,
    timeout: Option[software.amazon.awscdk.Duration] = None,
    parameters: Option[Map[String, _]] = None
  ): software.amazon.awscdk.services.stepfunctions.tasks.CallAwsServiceProps =
    (new software.amazon.awscdk.services.stepfunctions.tasks.CallAwsServiceProps.Builder)
      .service(service)
      .iamResources(iamResources.asJava)
      .action(action)
      .iamAction(iamAction.orNull)
      .resultPath(resultPath.orNull)
      .resultSelector(resultSelector.map(_.asJava).orNull)
      .heartbeat(heartbeat.orNull)
      .integrationPattern(integrationPattern.orNull)
      .outputPath(outputPath.orNull)
      .comment(comment.orNull)
      .inputPath(inputPath.orNull)
      .timeout(timeout.orNull)
      .parameters(parameters.map(_.asJava).orNull)
      .build()
}

==> aws-cdk-scala-stepfunctions_2.13-0.1.4-sources.jar: io/burkard/cdk/services/stepfunctions/CallAwsServiceProps.scala <==
package io.burkard.cdk.services.stepfunctions

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CallAwsServiceProps {

  def apply(
    iamAction: Option[String] = None,
    resultPath: Option[String] = None,
    service: Option[String] = None,
    iamResources: Option[List[String]] = None,
    resultSelector: Option[Map[String, _]] = None,
    heartbeat: Option[software.amazon.awscdk.Duration] = None,
    integrationPattern: Option[software.amazon.awscdk.services.stepfunctions.IntegrationPattern] = None,
    outputPath: Option[String] = None,
    comment: Option[String] = None,
    inputPath: Option[String] = None,
    timeout: Option[software.amazon.awscdk.Duration] = None,
    parameters: Option[Map[String, _]] = None,
    action: Option[String] = None
  ): software.amazon.awscdk.services.stepfunctions.tasks.CallAwsServiceProps =
    (new software.amazon.awscdk.services.stepfunctions.tasks.CallAwsServiceProps.Builder)
      .iamAction(iamAction.orNull)
      .resultPath(resultPath.orNull)
      .service(service.orNull)
      .iamResources(iamResources.map(_.asJava).orNull)
      .resultSelector(resultSelector.map(_.asJava).orNull)
      .heartbeat(heartbeat.orNull)
      .integrationPattern(integrationPattern.orNull)
      .outputPath(outputPath.orNull)
      .comment(comment.orNull)
      .inputPath(inputPath.orNull)
      .timeout(timeout.orNull)
      .parameters(parameters.map(_.asJava).orNull)
      .action(action.orNull)
      .build()
}
